%% This is file `du-journals.cls',
%%
%% Copyright 2012 The LaTeX3 Project and Mortaza Abtahi
%%
%%
\NeedsTeXFormat{LaTeX2e}
\ProvidesClass{du-journals}[2012/05/26 v1.1]
\LoadClass[10pt,a4paper,twoside]{article}
%%
\usepackage{amssymb}
\usepackage{amsfonts}
\usepackage{amsthm}
\usepackage{graphicx}
%%
%%
\hoffset-1in
\oddsidemargin3.5cm
\textwidth14cm
\evensidemargin3.5cm
\voffset-1in
\topmargin2cm
%%
%%
\def\abb{Abb. Journal Title}%
\def\full{Full Journal Title}%
%%
\newcommand{\jtitle}{Full Journal Title}
\newcommand{\journal}[1]{\renewcommand{\jtitle}{#1}}
\newcommand{\journaltitle}{\sffamily\bfseries\jtitle}
\newlength{\jtitlewidth}\setlength{\jtitlewidth}{0pt}
\settowidth{\jtitlewidth}{\journaltitle}
%%
\def\logo{%
\newlength{\logowidth}
\setlength{\logowidth}{3cm}
\begin{minipage}{\logowidth}
\rule{\logowidth}{.2ex}\vspace*{-.5ex}
\raggedright\journaltitle
\vspace*{-1.5ex}\newline\rule{\logowidth}{.5ex}
\end{minipage}
}
%%
%%
\def\ABB{%
\begin{minipage}{64mm}
\footnotesize\jtitle\\
Vol. 1 Summer 2021\\
\copyright Available online at http://jhap.du.ac.ir\\
DOI:
\end{minipage}}
%%
%%
\def\ps@firstpage{%
    \def\@oddfoot{\hfil\thepage\hfil}%
    \def\@oddhead{\ABB\hfil\logo}%
    \let\@evenfoot\@empty%
    \let\@evenhead\@empty%
    \let\@mkboth\@gobbletwo
    \let\chaptermark\@gobble
    \let\sectionmark\@gobble}
%%
%%
\usepackage{ifthen}
%%
\providecommand{\thanks}{}
\renewcommand{\thanks}[1]{\footnote{#1}}
\renewcommand{\thempfootnote}{\fnsymbol{mpfootnote}}
%%
%Transfer argument of \title command to \duj@title
\renewcommand{\title}[1]{\newcommand{\duj@title}{#1}}
\newcommand{\duj@subtitle}{\duj@title}
\newcommand{\subtitle}[1]{\renewcommand{\duj@subtitle}{#1}}
%%
%Transfer argument of \author command to TeX commands
%of the form \author@n, with optional labels stored in \authorlabel@n
\newcounter{author}
\renewcommand{\author}[2][]
{
   \stepcounter{author}
   \@namedef{author@\theauthor}{#2}
   \@namedef{authorlabel@\theauthor}{#1}
}
%%
%Transfer argument of \address command to TeX commands
%of the form \address@n, with optional labels stored in \addresslabel@n
\newcounter{address}
\newcommand{\address}[2][]
{
   \stepcounter{address}
   \@namedef{address@\theaddress}{#2}
   \@namedef{addresslabel@\theaddress}{#1}
}
%%
%\newcounter{email}
%\newcommand{\email}[2][]
%{
%   \stepcounter{email}
%   \@namedef{email@\theemail}{#2}
%   \@namedef{emaillabel@\theemail}{#1}
%}
%%
%Transfer argument of \contact commands to \duj@contact
%\newcommand{\contact}[1]{\newcommand{\duj@contact}{#1}}
%\newcommand{\contactaddress}[1]{\newcommand{\duj@address}{#1}}
%\newcommand{\contactphone}[1]{\newcommand{\duj@phone}{#1}}
%\newcommand{\contactfax}[1]{\newcommand{\duj@fax}{#1}}
%\newcommand{\contactemail}[1]{\newcommand{\duj@email}{#1}}
%%
%Transfer argument of \category command to \duj@category
%\newcommand{\category}[1]{\newcommand{\duj@category}{#1}}
%%
%%
%%
%%
%Transfer argument of \keywords command to \duj@keywords
%\newcommand{\keys}{Enter keywords}
%\newcommand{\keywords}[1]{\renewcommand{\keys}{#1}\par\textit{Keywords}: \keys}
%%
%%
%%
%%
\def\maketitle{%
\vspace*{8ex}
\noindent
\begin{minipage}{.8\textwidth}
\begin{flushleft}
\renewcommand{\baselinestretch}{1.1}
\large\bfseries\duj@title
\end{flushleft}
\end{minipage}
\par
\vspace{5ex}
{\small
      \newcounter{c@author}
      \ifthenelse{\value{address}=1}{%No address references required if there is only one
         \@nameuse{author@1}%
         \stepcounter{c@author}%
         \whiledo{\value{c@author}<\value{author}}%
            {\stepcounter{c@author}$\ \cdot\ $\@nameuse{author@\thec@author}}\\%
      }
      {%Add address references after the author's name
         \@nameuse{author@1}${}^{\ref{\@nameuse{authorlabel@1}}}$%
         \stepcounter{c@author}%
         \whiledo{\value{c@author}<\value{author}}%
            {\stepcounter{c@author}$\ \cdot\ $\@nameuse{author@\thec@author}%
             ${}^{\ref{\@nameuse{authorlabel@\thec@author}}}$%
         }
      }
}
      \ifthenelse{\value{address}>0}
      {
         \ifthenelse{\value{address}=1}
         {%Output the address without any reference symbols
            {\footnotesize\@nameuse{address@1}}
         }
         {%Output the addresses as an enumerated list
            \newcounter{c@address}
            \begin{list}
               {{}$^{\arabic{c@address}}$}
               {\usecounter{c@address}%
                \setlength{\itemindent}{0pt}%
                \setlength{\itemsep}{0pt}%
                \setlength{\labelsep}{0.1in}%
                \setlength{\labelwidth}{0.2in}%
                \setlength{\leftmargin}{0.4in}
                \setlength{\parsep}{0pt}%
                \setlength{\rightmargin}{\leftmargin}
                \setlength{\topsep}{2pt}%
                \footnotesize}
               \whiledo{\value{c@address}<\value{address}}
               {
                  \item \label{\@nameuse{addresslabel@\thec@address}}%
                  \@nameuse{address@\thec@address}%
               }
            \end{list}
         }
      }
      {
         \relax
      }
\thispagestyle{firstpage}}
%%
\newcommand{\authorhead}{}
\ifthenelse{\value{author}=1}%
{\renewcommand{\authorhead}{\@nameuse{author@1}}}%
{\renewcommand{\authorhead}{\@nameuse{author@1} et al.}}%
%%
%%
\renewenvironment{abstract}%
{\maketitle\vspace*{2ex}\begin{quote}\textbf{Abstract}.\small}
{\end{quote}}
%%
%%
\newenvironment{keywords}%
{\begin{quote}\small\textit{Keywords}:}
{\end{quote}}
%%
%%
\def\ps@dups{%
    \let\@oddfoot\@empty\let\@evenfoot\@empty
    \def\@oddhead{\hfil{\small\duj@subtitle}\hfil\thepage}%
    \def\@evenhead{\thepage\hfil{\small\authorhead}\hfil}%
    \let\@mkboth\markboth}
%%
\pagestyle{dups}
\endinput



%Define the abstract environment to output all the information collected
\renewenvironment{abstract}{%Commands for the beginning of the abstract environment
   \begin{center}
      Abstract
   \end{center}
   \vspace{3ex}
   \begin{minipage}[t][5in][t]{6in}
      \begin{center}
         {\large\bfseries \duj@title}\\
      \vspace{1ex}
      \newcounter{c@author}
      \ifthenelse{\value{address}=1}
      {%No address references required if there is only one
         \@nameuse{author@1}%
         \stepcounter{c@author}%
         \whiledo{\value{c@author}<\value{author}}%
            {\stepcounter{c@author}, \@nameuse{author@\thec@author}}\\%
      }
      {%Add address references after the author's name
         \@nameuse{author@1}${}^{\ref{\@nameuse{authorlabel@1}}}$%
         \stepcounter{c@author}%
         \whiledo{\value{c@author}<\value{author}}%
            {\stepcounter{c@author}, \@nameuse{author@\thec@author}%
             ${}^{\ref{\@nameuse{authorlabel@\thec@author}}}$%
         }
      }
      \ifthenelse{\value{address}>0}
      {
         \ifthenelse{\value{address}=1}
         {%Output the address without any reference symbols
            {\slshape\small \@nameuse{address@1}}
         }
         {%Output the addresses as an enumerated list
            \newcounter{c@address}
            \begin{list}
               {{}$^{\arabic{c@address}}$}
               {\usecounter{c@address}%
                \setlength{\itemindent}{0pt}%
                \setlength{\itemsep}{0pt}%
                \setlength{\labelsep}{0.1in}%
                \setlength{\labelwidth}{0.2in}%
                \setlength{\leftmargin}{0.4in}
                \setlength{\parsep}{0pt}%
                \setlength{\rightmargin}{\leftmargin}
                \setlength{\topsep}{2pt}%
                \slshape\small}
               \whiledo{\value{c@address}<\value{address}}
               {
                  \item \label{\@nameuse{addresslabel@\thec@address}}%
                  \@nameuse{address@\thec@address}%
               }
            \end{list}
         }
      }
      {
         \relax
      }
      \end{center}
}
{%Commands for the end of the abstract environment
   \end{minipage}
   \rule{6in}{1pt}
   \begin{center}
   \ifthenelse{\equal{\duj@keywords}{}}
   {\relax}
   {{\slshape Keywords : }\duj@keywords \\}
   \vspace{0.5ex}
   \ifthenelse{\equal{\duj@category}{}}
   {\relax}
   {{\slshape Category: }\duj@category \\}
   \vspace{1ex}
   \begin{small}
   \framebox[6in]
   {
      \parbox[t]{3in}{\duj@contact \\ \duj@address}
      \parbox[t]{2.5in}{Email: \duj@email \\
                        Tel: \duj@phone \\
                        Fax: \duj@fax}
   }
   \end{small}
   \end{center}
}
%%
%% End of file `casabs.cls'.
